The program uses the BusOut Class to make a counter

Dependencies:   mbed

Fork of BusOut_HelloWorld by mbed_example

Revision:
3:b83cb0af21b0
Parent:
2:76f66b714f20
Child:
4:c01479bfd551
--- a/main.cpp	Thu Oct 16 07:39:18 2014 +0000
+++ b/main.cpp	Thu Oct 16 07:42:24 2014 +0000
@@ -1,19 +1,33 @@
 /***********************************************
 *file name :number show
 *creator: Jacob Shi
 *Time :2014/10/16
 *Description: The program use the BusOut Class to 
 *realize a counter(0-9)
  *************************************************/
 #include "mbed.h"
 char data[10]={0xC0,0xF9,0xA4,0xB0,0x99,0x92,0x82,0xF8,0x80,0x90};
-BusOut port(p21, p22, p23, p24,p25,p26,p27,p28);
+char i=0;
+BusInOut key(p5);
+BusInOut portnum(p21,p22,p23,p24,p25,p26,p27,p28);
+int main() 
+  {
+    key.input();
+    portnum.output();
+    while(1) 
+    {
 
-int main() {
-    while(1) {
-        for(int i=0; i<10; i++) {
-            port = data[i];
-            wait(1);
+            portnum=0x00;
+           if(key==0)
+           {
+                wait_ms(10);
+                if(key==0)
+                {
+                        while(!key);
+                        portnum=data[i];
+                        (i++)%10;
+                }
+
+           }     
+
         }
-    }
-}
\ No newline at end of file
+  }
\ No newline at end of file
@@ -1,19 +1,33 @@
-/***********************************************
-*file name :number show
-*creator: Jacob Shi
-*Time :2014/10/16
-*Description: The program use the BusOut Class to 
-*realize a counter(0-9)
- *************************************************/
+/*************************************************
+*file name : switch point
+*creator:Jacob Shi
+*Time:2014/10/16
+*Description: uses to key to control the counter
+*************************************************/
 #include "mbed.h"
 char data[10]={0xC0,0xF9,0xA4,0xB0,0x99,0x92,0x82,0xF8,0x80,0x90};